@@ -3,19 +3,19 @@
 
 setMethod("geomtype", signature(x="SpatVector"),
 	function(x){
-		x@ptr$type()
+		x@pntr$type()
 	}
 )
 setMethod("geomtype", signature(x="SpatVectorProxy"),
 	function(x){
-		x@ptr$v$type()
+		x@pntr$v$type()
 	}
 )
 
 
 setMethod("datatype", signature(x="SpatVector"),
 	function(x){
-		x@ptr$df$get_datatypes()
+		x@pntr$df$get_datatypes()
 	}
 )
 
@@ -50,17 +50,17 @@ setMethod("geomtype", signature(x="Spatial"),
 setMethod("geom", signature(x="SpatVector"),
 	function(x, wkt=FALSE, hex=FALSE, wkb=FALSE, df=FALSE, list=FALSE, xnm="x", ynm="y"){
 		if (hex) {
-			x@ptr$hex()
+			x@pntr$hex()
 		} else if (wkt) {
-			x@ptr$getGeometryWKT()
+			x@pntr$getGeometryWKT()
 			# or via geos with
-			# x@ptr$wkt()
+			# x@pntr$wkt()
 		} else if (list) {
-			x@ptr$get_geometryList(xnm, ynm)
+			x@pntr$get_geometryList(xnm, ynm)
 		} else if (wkb) {
-			x@ptr$wkb_raw()
+			x@pntr$wkb_raw()
 		}	else {
-			g <- x@ptr$get_geometry()
+			g <- x@pntr$get_geometry()
 			g <- do.call(cbind, g)
 			colnames(g) <- c("geom", "part", "x", "y", "hole")[1:ncol(g)]
 			if (df) {
@@ -77,14 +77,14 @@ setMethod("crds", signature(x="SpatVector"),
 		if (list) {
 			gt <- geomtype(x) 
 			if (gt == "lines") {
-				x@ptr$linesNA()
+				x@pntr$linesNA()
 			} else if (gt == "polygons") {
-				x@ptr$polygonsList()			
+				x@pntr$polygonsList()			
 			} else {
-				x@ptr$coordinates()
+				x@pntr$coordinates()
 			}
 		} else {
-			g <- x@ptr$coordinates()
+			g <- x@pntr$coordinates()
 			g <- do.call(cbind, g)
 			colnames(g) <- c("x", "y")
 			if (df) {
@@ -101,7 +101,7 @@ setMethod("crds", signature(x="SpatRaster"),
 	function(x, df=FALSE, na.rm=TRUE, na.all=FALSE){
 #		crds( as.points(x, values=(hasValues(x) || (na.rm)), na.rm=na.rm, na.all=na.all), df=df)
 		opt <- spatOptions()
-		out <- x@ptr$crds(na.rm, na.all, opt)
+		out <- x@pntr$crds(na.rm, na.all, opt)
 		messages(x)
 		if (df) {
 			out <- data.frame(out)
@@ -122,15 +122,15 @@ setMethod("dim", signature(x="SpatVector"),
 
 setMethod("dim", signature(x="SpatVectorProxy"),
 	function(x){
-		c(x@ptr$v$geom_count, x@ptr$v$ncol())
+		c(x@pntr$v$geom_count, x@pntr$v$ncol())
 	}
 )
 
 
 as.data.frame.SpatVector <- function(x, row.names=NULL, optional=FALSE, geom=NULL, ...) {
-	d <- .getSpatDF(x@ptr$df, ...)
+	d <- .getSpatDF(x@pntr$df, ...)
 	# fix empty names
-	colnames(d)[1:ncol(x)] <- x@ptr$names
+	colnames(d)[1:ncol(x)] <- x@pntr$names
 	if (!is.null(geom)) {
 		geom <- match.arg(toupper(geom), c("WKT", "HEX", "XY"))
 		if (geom == "XY") {
@@ -158,7 +158,7 @@ setMethod("as.data.frame", signature(x="SpatVector"), as.data.frame.SpatVector)
 
 get.data.frame <- function(x) {
 	v <- vect()
-	v@ptr <- x@ptr$v
+	v@pntr <- x@pntr$v
 	d <- as.data.frame(v)
 	d[0,,drop=FALSE]
 }
@@ -173,7 +173,7 @@ setMethod("as.list", signature(x="SpatVector"), as.list.SpatVector)
 
 setMethod ("expanse", "SpatVector",
 	function(x, unit="m", transform=TRUE) {
-		a <- x@ptr$area(unit, transform, double());
+		a <- x@pntr$area(unit, transform, double());
 		x <- messages(x, "expanse");
 		return(abs(a))
 	}
@@ -182,15 +182,23 @@ setMethod ("expanse", "SpatVector",
 
 setMethod("perim", signature(x="SpatVector"),
 	function(x) {
-		p <- x@ptr$length();
+		p <- x@pntr$length();
 		x <- messages(x, "perim");
-		return(p)
+		p
+	}
+)
+
+setMethod("nseg", signature(x="SpatVector"),
+	function(x) {
+		p <- x@pntr$nsegments();
+		x <- messages(x, "nseg");
+		p
 	}
 )
 
 setMethod("length", signature(x="SpatVector"),
 	function(x) {
-		x@ptr$size()
+		x@pntr$size()
 	}
 )
 
@@ -198,9 +206,9 @@ setMethod("length", signature(x="SpatVector"),
 setMethod("fillHoles", signature(x="SpatVector"),
 	function(x, inverse=FALSE) {
 		if (inverse) {
-			x@ptr <- x@ptr$get_holes()
+			x@pntr <- x@pntr$get_holes()
 		} else {
-			x@ptr <- x@ptr$remove_holes()
+			x@pntr <- x@pntr$remove_holes()
 		}
 		messages(x, "fillHoles")
 	}
@@ -210,7 +218,7 @@ setMethod("fillHoles", signature(x="SpatVector"),
 
 #setMethod("eliminate", signature(x="SpatVector"),
 #	function(x, y) {
-#		x@ptr <- x@ptr$eliminate(y@ptr)
+#		x@pntr <- x@pntr$eliminate(y@pntr)
 #		messages(x)
 #	}
 #)
@@ -220,9 +228,9 @@ setMethod("fillHoles", signature(x="SpatVector"),
 setMethod("centroids", signature(x="SpatVector"),
 	function(x, inside=FALSE) {
 		if (inside) {
-			x@ptr <- x@ptr$point_on_surface(TRUE)
+			x@pntr <- x@pntr$point_on_surface(TRUE)
 		} else {
-			x@ptr <- x@ptr$centroid(TRUE)
+			x@pntr <- x@pntr$centroid(TRUE)
 		}
 		messages(x, "centroids")
 	}
@@ -232,7 +240,7 @@ setMethod("centroids", signature(x="SpatVector"),
 
 setMethod("densify", signature(x="SpatVector"),
 	function(x, interval, equalize=TRUE, flat=FALSE) {
-		x@ptr <- x@ptr$densify(interval, equalize, flat)
+		x@pntr <- x@pntr$densify(interval, equalize, flat)
 		messages(x, "densify")
 	}
 )
@@ -245,7 +253,7 @@ setMethod("normalize.longitude", signature(x="SpatVector"),
 		x[[fname]] <- 1:nrow(x)
 		d <- values(x)
 		out <- x[,fname]
-		out@ptr <- out@ptr$normalize_longitude()
+		out@pntr <- out@pntr$normalize_longitude()
 		out <- messages(out)
 		a <- aggregate(out, fname, count=FALSE)
 		if (nc > 0) {
