@@ -6,16 +6,16 @@ setMethod("makeTiles", signature(x="SpatRaster"),
 		if (filename == "") error("makeTiles", "filename cannot be empty")
 		opt <- spatOptions(filename="", overwrite=overwrite, ...)
 		if (inherits(y, "SpatRaster")) {
-			ff <- x@ptr$make_tiles(y@ptr, extend[1], buffer, na.rm[1], filename, opt)
+			ff <- x@pntr$make_tiles(y@pntr, extend[1], buffer, na.rm[1], filename, opt)
 		} else if (inherits(y, "SpatVector")) {
-			ff <- x@ptr$make_tiles_vect(y@ptr, extend[1], buffer, na.rm[1], filename, opt)		
+			ff <- x@pntr$make_tiles_vect(y@pntr, extend[1], buffer, na.rm[1], filename, opt)
 		} else if (is.numeric(y)) {
 			if (length(y) > 2) {
 				error("makeTiles", "expected one or two numbers")
 			}
 			y <- rep_len(y, 2)
 			y <- aggregate(rast(x), y)
-			ff <- x@ptr$make_tiles(y@ptr, extend[1], buffer, na.rm[1], filename, opt)			
+			ff <- x@pntr$make_tiles(y@pntr, extend[1], buffer, na.rm[1], filename, opt)
 		} else {
 			error("makeTiles", "y must be numeric or a SpatRaster or SpatVector")
 		}
@@ -30,16 +30,16 @@ setMethod("getTileExtents", signature(x="SpatRaster"),
 
 		opt <- spatOptions(filename="")
 		if (inherits(y, "SpatRaster")) {
-			e <- x@ptr$get_tiles_ext(y@ptr, extend[1], buffer)
+			e <- x@pntr$get_tiles_ext(y@pntr, extend[1], buffer)
 		} else if (inherits(y, "SpatVector")) {
-			e <- x@ptr$get_tiles_ext_vect(y@ptr, extend[1], buffer)		
+			e <- x@pntr$get_tiles_ext_vect(y@pntr, extend[1], buffer)
 		} else if (is.numeric(y)) {
 			if (length(y) > 2) {
 				error("getTileExtents", "expected one or two numbers")
 			}
 			y <- rep_len(y, 2)
 			y <- aggregate(rast(x), y)
-			e <- x@ptr$get_tiles_ext(y@ptr, extend[1], buffer)
+			e <- x@pntr$get_tiles_ext(y@pntr, extend[1], buffer)
 		} else {
 			error("getTileExtents", "y must be numeric or a SpatRaster or SpatVector")
 		}
@@ -75,12 +75,17 @@ setMethod("vrt", signature(x="character"),
 		r <- rast()
 		if (is.null(options)) {
 			options=""[0]
-		} 
-		f <- r@ptr$make_vrt(x, options, opt)
+		}
+		f <- r@pntr$make_vrt(x, options, opt)
 		messages(r, "vrt")
+		messages(opt, "vrt")
 		if (set_names) {
 			v <- readLines(f)
-			nms <- names(rast(x[1]))
+			if ("-separate" %in% options) {
+			    nms <- unlist(lapply(sprc(x), names))
+			} else {
+			    nms <- names(rast(x[1]))
+			}
 			i <- grep("band=", v)
 			if (length(i) == length(nms)) {
 				nms <- paste0("<Description>", nms, "</Description>")
@@ -88,8 +93,28 @@ setMethod("vrt", signature(x="character"),
 				writeLines(v, f)
 			}
 		}
-		if (return_filename) return(f)
-		rast(f)
+		if (return_filename) {
+			f
+		} else {
+			rast(f)
+		}
+	}
+)
+
+
+setMethod("vrt", signature(x="SpatRasterCollection"),
+	function(x, filename="", options=NULL, overwrite=FALSE, return_filename=FALSE) {
+		opt <- spatOptions(filename, overwrite=overwrite)
+		if (is.null(options)) {
+			options=""[0]
+		}
+		f <- x@pntr$make_vrt(options, FALSE, opt)
+		messages(x, "vrt")
+		if (return_filename) {
+			f
+		} else {
+			rast(f)
+		}
 	}
 )
 
@@ -103,7 +128,7 @@ vrt_tiles <- function(x) {
 	}
 	x <- grep(".vrt$", x, ignore.case =TRUE, value=TRUE)
 	if (length(x) == 0) {
-		error("vrt_sources", 'no filenames with extension ".vrt"')	
+		error("vrt_sources", 'no filenames with extension ".vrt"')
 	}
 	tiles <- lapply(x, function(f) {
 			v <- readLines(f)
