@@ -186,6 +186,7 @@ setMethod("time<-", signature(x="SpatRaster"),
 			value <- tstep
 			tstep <- ""
 		}
+		x@pntr <- x@pntr$deepcopy()
 		if (is.null(value)) {
 			x@pntr$setTime(0[0], "remove", "")
 			return(x)
@@ -258,6 +259,14 @@ setMethod("time<-", signature(x="SpatRaster"),
 				stept <- "raw"
 			}
 		}
+		if (any(is.na(value))) {
+			if (!all(is.na(value))) {
+				error("time<-", "NAs are not allowed in time values (unless they are all NA)")
+			}
+			value <- value[0]
+			stept <- "remove"
+		}
+		
 		if (!x@pntr$setTime(as.numeric(value), stept, tzone)) {
 			error("time<-", "cannot set these values")
 		}
@@ -273,6 +282,7 @@ setMethod("time<-", signature(x="SpatRasterDataset"),
 			value <- tstep
 			tstep <- ""
 		}
+
 		tstep <- rep_len(tstep, length(x))
 
 		if (is.list(value)) {
@@ -302,6 +312,34 @@ setMethod("depth", signature(x="SpatRaster"),
 	}
 )
 
+setMethod("depthName", signature(x="SpatRaster"),
+	function(x) {
+		x@pntr$get_depth_name()
+	}
+)
+
+setMethod("depthName<-", signature(x="SpatRaster"),
+	function(x, value) {
+		x <- deepcopy(x)
+		x@pntr$set_depth_name(value)
+		x
+	}
+)
+
+
+setMethod("depthUnit", signature(x="SpatRaster"),
+	function(x) {
+		x@pntr$get_depth_unit()
+	}
+)
+
+setMethod("depthUnit<-", signature(x="SpatRaster"),
+	function(x, value) {
+		x <- deepcopy(x)
+		x@pntr$set_depth_unit(value)
+		x
+	}
+)
 
 setMethod("depth<-", signature(x="SpatRaster"),
 	function(x, value)  {
@@ -310,6 +348,9 @@ setMethod("depth<-", signature(x="SpatRaster"),
 			return(x)
 		}
 		value <- as.numeric(value)
+		if (any(is.na(value))) {
+			error("depth<-", "NAs are not allowed")
+		}
 		if (! x@pntr$setDepth(value)) {
 			error("depth<-", "cannot set these  values")
 		}
