@@ -1,8 +1,9 @@
 
 setMethod("update", signature(object="SpatRaster"),
-	function(object, names=FALSE, crs=FALSE, extent=FALSE) {
+	function(object, crs=FALSE, extent=FALSE) {
 		opt <- spatOptions()
-		ok <- object@pnt$update_meta(names, crs, extent, opt)
+		names <- FALSE
+		ok <- object@pntr$update_meta(names, crs, extent, opt)
 		messages(object, "update")
 		invisible(object)
 	}
