@@ -37,9 +37,17 @@ bool driverSupports(std::string driver, std::string option) {
 }
 
 
+#include "Rcpp.h"
+
 GDALDataset* SpatVector::write_ogr(std::string filename, std::string lyrname, std::string driver, bool append, bool overwrite, std::vector<std::string> options) {
 
     GDALDataset *poDS = NULL;
+	if (nrow() == 0) {
+		setError("SpatVector has no records to write");
+		return(poDS);		
+	}
+
+
 	if (!filename.empty()) {
 		if (file_exists(filename)) { // || path_exists(filename)) {
 			if ((!overwrite) && (!append)) {
@@ -57,6 +65,8 @@ GDALDataset* SpatVector::write_ogr(std::string filename, std::string lyrname, st
 //		}
 	}
 
+
+
 	if (append) {
 
 		#if GDAL_VERSION_MAJOR < 3
@@ -112,7 +122,7 @@ GDALDataset* SpatVector::write_ogr(std::string filename, std::string lyrname, st
 	if (nrow() > 0) {
 		SpatGeomType geomtype = geoms[0].gtype;
 		if (geomtype == points) {
-			wkb = wkbPoint;
+			wkb = is_multipoint() ? wkbMultiPoint : wkbPoint;
 		} else if (geomtype == lines) {
 			wkb = wkbMultiLineString;
 		} else if (geomtype == polygons) {
@@ -175,6 +185,8 @@ GDALDataset* SpatVector::write_ogr(std::string filename, std::string lyrname, st
 
 
 	std::vector<std::string> nms = get_names();
+	make_unique_names(nms);
+
 	std::vector<std::string> tps = df.get_datatypes();
 	OGRFieldType otype;
 	int nfields = nms.size();
@@ -182,6 +194,8 @@ GDALDataset* SpatVector::write_ogr(std::string filename, std::string lyrname, st
 
 
 	for (int i=0; i<nfields; i++) {
+		
+//		Rcpp::Rcout << nms[i] << std::endl;
 
 		OGRFieldSubType eSubType = OFSTNone;
 		if (tps[i] == "double") {
@@ -294,12 +308,30 @@ GDALDataset* SpatVector::write_ogr(std::string filename, std::string lyrname, st
 // points -- also need to do multi-points
 		OGRPoint pt;
 		if (wkb == wkbPoint) {
-			if (!std::isnan(geoms[i].parts[0].x[0])) {
-				pt.setX( geoms[i].parts[0].x[0] );
-				pt.setY( geoms[i].parts[0].y[0] );
+			if (geoms[i].parts.size() > 0) {
+				if (!std::isnan(geoms[i].parts[0].x[0])) {
+					pt.setX( geoms[i].parts[0].x[0] );
+					pt.setY( geoms[i].parts[0].y[0] );
+				}
 			}
 			poFeature->SetGeometry( &pt );
 
+		} else if (wkb == wkbMultiPoint) {
+
+			OGRMultiPoint poGeom;
+			for (size_t j=0; j<geoms[i].size(); j++) {
+				if (!std::isnan(geoms[i].parts[j].x[0])) {
+					pt.setX( geoms[i].parts[j].x[0] );
+					pt.setY( geoms[i].parts[j].y[0] );
+					poGeom.addGeometry(&pt);
+				}
+			}
+
+			if (poFeature->SetGeometry( &poGeom ) != OGRERR_NONE) {
+				setError("cannot set geometry");
+				return poDS;
+			}
+
 // lines
 		} else if (wkb == wkbMultiLineString) {
 			OGRMultiLineString poGeom;
